==> portal-transparencia-1.109.1.zip: BOOT-INF/classes/db/sql/contab/veiculo-gastos-por-data-requisicao.sql <==
SELECT A.ENTIDADE, A.MES,   
 A.MANUTENCAO, A.ABASTECIMENTO, A.PNEUS, A.BATERIAS, A.TOTALGERAL,        
        CASE WHEN (COALESCE((SELECT MIN(COALESCE(GP1.KMANTERIOR,0)) FROM FR_GASTOS_PORTAL GP1 
                             WHERE GP1.ENTIDADE = A.ENTIDADE 
                               AND GP1.EXERCICIO = A.EXERCICIO 
                               AND GP1.VEICULO = A.VEICULO 
                               AND EXTRACT(MONTH FROM GP1.DATAREQ) = A.MES 
                               AND COALESCE(GP1.KMANTERIOR,0) > 0),0) >= 0) AND
                      (COALESCE((SELECT MAX(COALESCE(GP1.KMATUAL,0)) FROM FR_GASTOS_PORTAL GP1 
                             WHERE GP1.ENTIDADE = A.ENTIDADE 
                               AND GP1.EXERCICIO = A.EXERCICIO 
                               AND GP1.VEICULO = A.VEICULO 
                               AND EXTRACT(MONTH FROM GP1.DATAREQ) = A.MES 
                               AND COALESCE(GP1.KMATUAL,0) > 0),0) > 0) THEN 
              ( COALESCE((SELECT MAX(GPATUAL.KMATUAL) FROM FR_GASTOS_PORTAL GPATUAL 
                          WHERE GPATUAL.ENTIDADE = A.ENTIDADE 
                            AND GPATUAL.EXERCICIO = A.EXERCICIO 
                            AND GPATUAL.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPATUAL.DATAREQ) = A.MES 
                            AND GPATUAL.KMATUAL > 0),0)) - 
              ( COALESCE((SELECT MIN(GPANT.KMANTERIOR) FROM FR_GASTOS_PORTAL GPANT 
                          WHERE GPANT.ENTIDADE = A.ENTIDADE 
                            AND GPANT.EXERCICIO = A.EXERCICIO 
                            AND GPANT.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPANT.DATAREQ) = A.MES 
                            AND GPANT.KMANTERIOR > 0),0)) 
        ELSE 
              ( COALESCE((SELECT MAX(GPATUAL1.KMATUAL) FROM FR_GASTOS_PORTAL GPATUAL1 
                          WHERE GPATUAL1.ENTIDADE = A.ENTIDADE 
                            AND GPATUAL1.EXERCICIO = A.EXERCICIO 
                            AND GPATUAL1.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPATUAL1.DATAREQ) = A.MES 
                            AND GPATUAL1.KMATUAL > 0),0)) - 
              ( COALESCE((SELECT MIN(GPANT1.KMATUAL) FROM FR_GASTOS_PORTAL GPANT1 
                          WHERE GPANT1.ENTIDADE = A.ENTIDADE 
                            AND GPANT1.EXERCICIO = A.EXERCICIO 
                            AND GPANT1.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPANT1.DATAREQ) = A.MES 
                            AND GPANT1.KMATUAL > 0),0)) END KMPERCORRIDO, 
        A.OBSERVACAO 
 FROM FR_GASTOS_PORTAL_DATAREQ A 
WHERE A.ENTIDADE = :entidade
  AND A.EXERCICIO = :exercicio
  AND A.VEICULO = :veiculo
ORDER BY A.MES

==> portal-transparencia-2.107.0.zip: BOOT-INF/classes/db/sql/contab/veiculo-gastos-por-data-requisicao.sql <==
SELECT A.ENTIDADE, A.MES,   
 A.MANUTENCAO, A.ABASTECIMENTO, A.PNEUS, A.BATERIAS, A.TOTALGERAL,        
        CASE WHEN (COALESCE((SELECT MIN(COALESCE(GP1.KMANTERIOR,0)) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1
                             WHERE GP1.ENTIDADE = A.ENTIDADE 
                               AND GP1.EXERCICIO = A.EXERCICIO 
                               AND GP1.VEICULO = A.VEICULO 
                               AND EXTRACT(MONTH FROM GP1.DATAREQ) = A.MES 
                               AND COALESCE(GP1.KMANTERIOR,0) > 0),0) >= 0) AND
                      (COALESCE((SELECT MAX(COALESCE(GP1.KMATUAL,0)) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1
                             WHERE GP1.ENTIDADE = A.ENTIDADE 
                               AND GP1.EXERCICIO = A.EXERCICIO 
                               AND GP1.VEICULO = A.VEICULO 
                               AND EXTRACT(MONTH FROM GP1.DATAREQ) = A.MES 
                               AND COALESCE(GP1.KMATUAL,0) > 0),0) > 0) THEN 
              ( COALESCE((SELECT MAX(GPATUAL.KMATUAL) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GPATUAL
                          WHERE GPATUAL.ENTIDADE = A.ENTIDADE 
                            AND GPATUAL.EXERCICIO = A.EXERCICIO 
                            AND GPATUAL.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPATUAL.DATAREQ) = A.MES 
                            AND GPATUAL.KMATUAL > 0),0)) - 
              ( COALESCE((SELECT MIN(GPANT.KMANTERIOR) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GPANT
                          WHERE GPANT.ENTIDADE = A.ENTIDADE 
                            AND GPANT.EXERCICIO = A.EXERCICIO 
                            AND GPANT.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPANT.DATAREQ) = A.MES 
                            AND GPANT.KMANTERIOR > 0),0)) 
        ELSE 
              ( COALESCE((SELECT MAX(GPATUAL1.KMATUAL) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GPATUAL1
                          WHERE GPATUAL1.ENTIDADE = A.ENTIDADE 
                            AND GPATUAL1.EXERCICIO = A.EXERCICIO 
                            AND GPATUAL1.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPATUAL1.DATAREQ) = A.MES 
                            AND GPATUAL1.KMATUAL > 0),0)) - 
              ( COALESCE((SELECT MIN(GPANT1.KMATUAL) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GPANT1
                          WHERE GPANT1.ENTIDADE = A.ENTIDADE 
                            AND GPANT1.EXERCICIO = A.EXERCICIO 
                            AND GPANT1.VEICULO = A.VEICULO 
                            AND EXTRACT(MONTH FROM GPANT1.DATAREQ) = A.MES 
                            AND GPANT1.KMATUAL > 0),0)) END KMPERCORRIDO, 
        A.OBSERVACAO 
 FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL_DATAREQ A
WHERE A.ENTIDADE = :entidade
  AND A.EXERCICIO = :exercicio
  AND A.VEICULO = :veiculo
ORDER BY A.MES
